==> 1.0.0.tar.gz: ios/Classes/SwiftWluperPluginFlutterPlugin.swift <==
import Flutter
import UIKit

@available(iOS 10, *)
public class SwiftWluperPluginFlutterPlugin: NSObject, FlutterPlugin, WluperInterface {

  var wluper:WluperSDK!
  var channel:FlutterMethodChannel!
  var x_api_key:String?
  var wluperLog = WluperLog()
  var result_asr:FlutterResult?
  var result_tree:FlutterResult?
    


  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "wluper_plugin_flutter", binaryMessenger: registrar.messenger())
    let instance = SwiftWluperPluginFlutterPlugin()
    instance.channel = channel
    registrar.addMethodCallDelegate(instance, channel: channel)
    
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    if (call.method == "WluperSDK") {
      if let args = call.arguments as? Dictionary<String, Any>{
          x_api_key = (args["x_api_key"] as! String)
          wluper = WluperSDK( _listener: self, _x_api_key: x_api_key!)
          result(0)
      }else{
        result(-1)
      }
    }
    else if (call.method == "cancelListening") {
      wluper.cancelListening()
      result(0)
    }
    else if (call.method == "startListening") {
        result_asr = result
        wluper.startListening()
    }
    else if (call.method == "understand") {
        if let args = call.arguments as? Dictionary<String, Any>{
            result_tree = result;
            let plain_text = (args["plain_text"] as! String)
            wluper.wluperTU(text: plain_text)
      }else{
        result(-1)
      }
    }
    else if (call.method == "WluperDeviceInfo") {
      if let args = call.arguments as? Dictionary<String, Any>{
        
        if let apikey = x_api_key {
            wluperLog.api_key = apikey
            wluperLog.device_id = (args["device_id"] as! String)
            wluperLog.model = (args["model"] as! String)
            wluperLog.os_name = (args["os_name"] as! String)
            wluperLog.os_version = (args["os_version"] as! String)
            wluperLog.sdk_version = (args["sdk_version"] as! String)
            wluper.setWluperLogBase(_wluperLog:wluperLog)
            result(0)
        }else{
            result(-1)
          }
        
        
      }else{
        result(-1)
      }
    }
    

    else {
      result(-1)
    } 
    
  }

    func WluperLiveText(text: String) {
        channel.invokeMethod("WluperLiveText", arguments: text)
      }

    func WluperError(error: String) {
        channel.invokeMethod("WluperError", arguments: error)
      }

    func WluperTree(tree: Any) {
        self.result_tree!(tree)
      }

    func WluperASR(plain_text: String) {
        self.result_asr!(plain_text)
    }
    
    func WluperEndOfSpeech(){
        channel.invokeMethod("WluperEndOfSpeech", arguments:nil)
    }
    
}

==> 1.1.0.tar.gz: ios/Classes/SwiftWluperPluginFlutterPlugin.swift <==
import Flutter
import UIKit

@available(iOS 10, *)
public class SwiftWluperPluginFlutterPlugin: NSObject, FlutterPlugin, WluperInterface {

  var wluper:WluperSDK!
  var channel:FlutterMethodChannel!
  var x_api_key:String?
  var log_api_key:String?
  var client_id:String?
  var wluperLog = WluperLog()
  var result_asr:FlutterResult?
  var result_tree:FlutterResult?



  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "wluper_plugin_flutter", binaryMessenger: registrar.messenger())
    let instance = SwiftWluperPluginFlutterPlugin()
    instance.channel = channel
    registrar.addMethodCallDelegate(instance, channel: channel)

  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    if (call.method == "WluperSDK") {
      if let args = call.arguments as? Dictionary<String, Any>{
          x_api_key = (args["x_api_key"] as! String)
          log_api_key = (args["log_api_key"] as! String)
          client_id = (args["client_id"] as! String)
          wluper = WluperSDK( _listener: self, _x_api_key: x_api_key!,_log_api_key:log_api_key!, _client_id:client_id! )
          result(0)
      }else{
        result(-1)
      }
    }
    else if (call.method == "cancelListening") {
      wluper.cancelListening()
      result(0)
    }
    else if (call.method == "startListening") {
        result_asr = result
        wluper.startListening()
    }
    else if (call.method == "understand") {
        if let args = call.arguments as? Dictionary<String, Any>{
            result_tree = result;
            let plain_text = (args["plain_text"] as! String)
            wluper.wluperTU(text: plain_text)
      }else{
        result(-1)
      }
    }
    else if (call.method == "WluperDeviceInfo") {
      if let args = call.arguments as? Dictionary<String, Any>{

        if let apikey = x_api_key {
            if let clientid = client_id{
                wluperLog.api_key = apikey
                wluperLog.client_id = clientid
                wluperLog.device_id = (args["device_id"] as! String)
                wluperLog.model = (args["model"] as! String)
                wluperLog.os_name = (args["os_name"] as! String)
                wluperLog.os_version = (args["os_version"] as! String)
                wluperLog.sdk_version = (args["sdk_version"] as! String)
                wluper.setWluperLogBase(_wluperLog:wluperLog)
                result(0)
            }
        }else{
            result(-1)
          }


      }else{
        result(-1)
      }
    }


    else {
      result(-1)
    }

  }

    func WluperLiveText(text: String) {
        channel.invokeMethod("WluperLiveText", arguments: text)
      }

    func WluperError(error: String) {
        channel.invokeMethod("WluperError", arguments: error)
      }

    func WluperTree(tree: Any) {
        self.result_tree!(tree)
      }

    func WluperASR(plain_text: String) {
        self.result_asr!(plain_text)
    }

    func WluperEndOfSpeech(){
        channel.invokeMethod("WluperEndOfSpeech", arguments:nil)
    }

}
